pub type InstanceHolder = WorldHolder;👎Deprecated:
renamed to WorldHolder.
Aliased Type
pub struct InstanceHolder {
pub partial: Arc<RwLock<RawRwLock, PartialWorld>>,
pub shared: Arc<RwLock<RawRwLock, World>>,
}Fields
partial: Arc<RwLock<RawRwLock, PartialWorld>>The slice of the world that this client actually has loaded, based on its render distance.
The combined [PartialWorld]s of all clients in the same world.
The distinction between this and partial is mostly only relevant if
you’re using a shared world (i.e. a swarm). If in doubt, prefer to use
the shared world.